==> clj-poly-0.2.20-20240713.171920-46.jar: polylith/clj/core/validator/datashape/toolsdeps2.clj <==
(ns ^:no-doc polylith.clj.core.validator.datashape.toolsdeps2
  (:require [malli.core :as m]
            [malli.error :as me]
            [malli.util :as mu]
            [polylith.clj.core.validator.datashape.shared :as shared]))

(defn validate-brick-config [config filename]
  (-> [:map
       [:paths [:* [:alt keyword? string?]]]
       [:deps [:map-of symbol? map?]]
       [:aliases {:optional true} [:map]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-project-dev-deps-config [config filename]
  (-> [:map
       [:aliases
        [:map
         [:dev shared/alias]
         [:test shared/alias]]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-project-deployable-config [config filename]
  (-> [:map
       [:paths {:optional true}
        [:* [:alt keyword? string?]]]
       [:deps {:optional true} [:map-of symbol? :map]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(def test-runner-constructor-schema
  [:or qualified-symbol? [:enum :default]])

(def test-runner-config-schema
  [:map
   [:create-test-runner {:optional true}
    [:or test-runner-constructor-schema
     [:repeat {:min 1} test-runner-constructor-schema]]]])

(def project-test-config-schema
  (mu/merge
   test-runner-config-schema
   [:map
    [:include {:optional true} vector?]
    [:exclude {:optional true} vector?]
    [:setup-fn {:optional true} qualified-symbol?]
    [:teardown-fn {:optional true} qualified-symbol?]]))

(def project-settings-schema
  [:map
   [:alias {:optional true} string?]
   [:test {:optional true}
    [:or project-test-config-schema
     vector?]]]) ;; legacy

(def workspace-schema
  [:map
   [:vcs {:optional true} [:or string? map?]]
   [:top-namespace string?]
   [:interface-ns {:optional true} string?]
   [:default-profile-name {:optional true} string?]
   [:compact-views {:optional true} set?]
   [:release-tag-pattern {:optional true} string?]
   [:stable-tag-pattern {:optional true} string?]
   [:tag-patterns {:optional true} map?]
   [:projects {:optional true}
    [:map-of :string project-settings-schema]]
   [:test {:optional true} test-runner-config-schema]])

(defn validate-workspace-config [config]
  (-> workspace-schema
      (m/explain config)
      (me/humanize)))

==> clj-poly-0.3.0-20251001.141253-3.jar: polylith/clj/core/validator/datashape/toolsdeps2.clj <==
(ns ^:no-doc polylith.clj.core.validator.datashape.toolsdeps2
  (:require [malli.core :as m]
            [malli.error :as me]
            [malli.util :as mu]
            [polylith.clj.core.validator.datashape.shared :as shared]))

(defn validate-brick-package-config
  "Validator for package.json files for components and bases"
  [config filename]
  (-> [:map
       [:name string?]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-deployable-project-package-config
  "Validator for package.json files for deployable projects, under the 'projects' directory"
  [config filename]
  (-> [:map
       [:dependencies map?]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-development-project-package-config
  "Validator for package.json file for the development project (at the workspace root)"
  [config filename]
  (-> [:map
       [:workspaces [:sequential string?]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-brick-deps-config [config filename]
  (-> [:map
       [:paths [:* [:alt keyword? string?]]]
       [:deps [:map-of symbol? map?]]
       [:aliases {:optional true} [:map]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-project-dev-deps-config [config filename]
  (-> [:map
       [:aliases
        [:map
         [:dev shared/alias]
         [:test shared/alias]]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(defn validate-project-deployable-config [config filename]
  (-> [:map
       [:paths {:optional true}
        [:* [:alt keyword? string?]]]
       [:deps {:optional true} [:map-of symbol? :map]]]
      (m/explain config)
      (me/humanize)
      (shared/error-message filename)))

(def test-runner-constructor-schema
  [:or qualified-symbol? [:enum :default]])

(def test-runner-config-schema
  [:map
   [:create-test-runner {:optional true}
    [:or test-runner-constructor-schema
     [:repeat {:min 1} test-runner-constructor-schema]]]])

(def project-test-config-schema
  (mu/merge
   test-runner-config-schema
   [:map
    [:include {:optional true} vector?]
    [:exclude {:optional true} vector?]
    [:setup-fn {:optional true} qualified-symbol?]
    [:teardown-fn {:optional true} qualified-symbol?]]))

(def project-settings-schema
  [:map
   [:alias {:optional true} string?]
   [:test {:optional true}
    [:or project-test-config-schema
     vector?]]]) ;; legacy

(def dialect
  [:enum "clj" "cljs"])

(def dialects-schema
  [:or
   [:vector {:min 1} dialect]
   [:set {:min 1} dialect]])

(def workspace-schema
  [:map
   [:vcs {:optional true} [:or string? map?]]
   [:top-namespace string?]
   [:interface-ns {:optional true} string?]
   [:default-profile-name {:optional true} string?]
   [:compact-views {:optional true} set?]
   [:release-tag-pattern {:optional true} string?]
   [:stable-tag-pattern {:optional true} string?]
   [:tag-patterns {:optional true} map?]
   [:projects {:optional true}
    [:map-of :string project-settings-schema]]
   [:test {:optional true} test-runner-config-schema]
   [:dialects {:optional true} dialects-schema]])

(defn validate-workspace-config [config]
  (-> workspace-schema
      (m/explain config)
      (me/humanize)))
